Crate codex_execpolicy

Crate codex_execpolicy 

Re-exports

pub use rule::NetworkRuleProtocol;
pub use rule::PatternToken;
pub use rule::PrefixPattern;
pub use rule::PrefixRule;
pub use rule::Rule;
pub use rule::RuleMatch;
pub use rule::RuleRef;

Modules

rule

Structs

ErrorLocation
Evaluation
ExecPolicyCheckCommand
Arguments for evaluating a command against one or more execpolicy files.
MatchOptions
Policy
PolicyParser
TextPosition
TextRange

Enums

AmendError
Decision
Error

Functions

blocking_append_allow_prefix_rule
Note this thread uses advisory file locking and performs blocking I/O, so it should be used with tokio::task::spawn_blocking when called from an async context.
blocking_append_network_rule
Note this function uses advisory file locking and performs blocking I/O, so it should be used with tokio::task::spawn_blocking when called from an async context.
prefix_rule_migration
removes legacy allow rules that newer codex versions no longer offer.

Type Aliases

Result