Structs
- Network
Rule - Prefix
Pattern - Prefix matcher for commands with support for alternative match tokens. First token is fixed since we key by the first token in policy.
- Prefix
Rule
Enums
- Network
Rule Protocol - Pattern
Token - Matches a single command token, either a fixed string or one of several allowed alternatives.
- Rule
Match