pub struct PrefixPattern {
pub first: Arc<str>,
pub rest: Arc<[PatternToken]>,
}Expand description
Prefix matcher for commands with support for alternative match tokens. First token is fixed since we key by the first token in policy.
Fields
first: Arc<str>rest: Arc<[PatternToken]>Implementations
Sourceimpl PrefixPattern
impl PrefixPattern