Re-exports
pub use rule::NetworkRuleProtocol;pub use rule::PatternToken;pub use rule::PrefixPattern;pub use rule::PrefixRule;pub use rule::Rule;pub use rule::RuleMatch;pub use rule::RuleRef;
Modules
Structs
- Error
Location - Evaluation
- Exec
Policy Check Command - Arguments for evaluating a command against one or more execpolicy files.
- Match
Options - Policy
- Policy
Parser - Text
Position - Text
Range
Enums
Functions
- blocking_
append_ allow_ prefix_ rule - Note this thread uses advisory file locking and performs blocking I/O, so it should be used with
tokio::task::spawn_blockingwhen called from an async context. - blocking_
append_ network_ rule - Note this function uses advisory file locking and performs blocking I/O, so it should be used
with
tokio::task::spawn_blockingwhen called from an async context. - prefix_
rule_ migration - removes legacy allow rules that newer codex versions no longer offer.