Module rule

Module rule 

Structs

NetworkRule
PrefixPattern
Prefix matcher for commands with support for alternative match tokens. First token is fixed since we key by the first token in policy.
PrefixRule

Enums

NetworkRuleProtocol
PatternToken
Matches a single command token, either a fixed string or one of several allowed alternatives.
RuleMatch

Traits

Rule

Type Aliases

RuleRef